@@ -1,6 +1,6 @@
 /* continuations.c -- continuations, much stack hackery..
    Copyright (C) 2000 John Harper <john@dcs.warwick.ac.uk>
-   $Id: continuations.c,v 1.45 2001/09/16 00:29:40 jsh Exp $
+   $Id: continuations.c 2913 2008-08-05 19:11:08Z chrisb $
 
    This file is part of librep.
 
@@ -192,8 +192,8 @@ struct rep_barrier_struct {
     rep_thread *head, *tail;
     rep_thread *susp_head, *susp_tail;
     short depth;
-    u_int closed : 1;
-    u_int targeted : 1;		/* may contain continuations */
+    unsigned int closed : 1;
+    unsigned int targeted : 1;		/* may contain continuations */
 };
 
 /* List of all currently active barriers (on the current stack) */
@@ -458,7 +458,9 @@ save_stack (rep_continuation *c)
 
     FLUSH_REGISTER_WINDOWS;
 
-#if defined (__GNUC__) && !defined (BROKEN_ALPHA_GCC)
+    /* __builtin_frame_address doesn't give the right thing on athlon64 */
+
+#if defined (__GNUC__) && !defined (BROKEN_ALPHA_GCC) && !defined (__x86_64)
     c->stack_top = __builtin_frame_address (0);
 #else
     c->stack_top = (char *) &size;
@@ -735,7 +737,7 @@ primitive_call_cc (repv (*callback)(rep_continuation *, void *), void *data,
 	save_stack (c);
 
 	DB (("call/cc: saved %p; real_size=%lu (%u)\n",
-	     c, (u_long) c->real_size, rep_stack_bottom - c->stack_top));
+	     c, (unsigned long) c->real_size, rep_stack_bottom - c->stack_top));
 
 	ret = callback (c, data);
 
@@ -1111,7 +1113,7 @@ thread_yield (void)
 }
 
 static void
-thread_suspend (rep_thread *t, u_long msecs,
+thread_suspend (rep_thread *t, unsigned long msecs,
 		rep_bool (*poll)(rep_thread *t, void *arg), void *poll_arg)
 {
     rep_barrier *root = t->cont->root;
@@ -1146,7 +1148,7 @@ thread_suspend (rep_thread *t, u_long msecs,
 	thread_invoke ();
 }
 
-u_long
+unsigned long
 rep_max_sleep_for (void)
 {
     rep_barrier *root = root_barrier;
@@ -1402,7 +1404,7 @@ DEFUN("continuation-callable-p", Fcontinuation_callable_p,
     return rep_signal_arg_error (cont, 1);
 }
 
-u_long
+unsigned long
 rep_max_sleep_for (void)
 {
     return UINT_MAX;
