@@ -1,6 +1,6 @@
 /* find.c -- Searching and replacing
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: find.c,v 1.33 2001/08/02 07:12:36 jsh Exp $
+   $Id: find.c 2913 2008-08-05 19:11:08Z chrisb $
 
    This file is part of Jade.
 
@@ -132,7 +132,7 @@ rep_string_modified (repv string)
 static void
 mark_cached_regexps(void)
 {
-    u_long total = 0;
+    unsigned long total = 0;
     struct cached_regexp *x = cached_regexps, *xp = 0;
     while(x != 0 && total < regexp_cache_limit)
     {
@@ -440,7 +440,7 @@ character `\'. If the STRING does not contain any regexp meta-characters
 it is returned as-is (un-copied).
 ::end:: */
 {
-    u_char *buf, *s;
+    char *buf, *s;
     int buflen = 128, slen, i = 0;
     rep_bool quoted = rep_FALSE;
     repv res = rep_NULL;
@@ -452,12 +452,12 @@ it is returned as-is (un-copied).
 	goto error;
     while(slen-- > 0)
     {
-	u_char c;
+	char c;
 	/* Ensure string is long enough, this saves doing this twice. */
 	if(i + 2 >= buflen)
 	{
 	    int newlen = buflen * 2;
-	    u_char *newbuf = rep_alloc(newlen);
+	    char *newbuf = rep_alloc(newlen);
 	    if(!newbuf)
 		goto error;
 	    memcpy(newbuf, buf, i);
