@@ -1,6 +1,6 @@
 /* lispmach.h -- Interpreter for compiled Lisp forms
 
-   $Id: lispmach.h,v 1.9 2003/09/04 05:58:56 jsh Exp $
+   $Id: lispmach.h 2913 2008-08-05 19:11:08Z chrisb $
 
    Copyright (C) 1993, 1994, 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -191,7 +191,7 @@ list_ref (repv list, int elt)
     do {					\
 	ASSERT (STK_USE <= v_stkreq);		\
 	ASSERT (BIND_USE <= b_stkreq + 1);	\
-	ASSERT ((pc - rep_STR (code)) < rep_STRING_LEN (code)); \
+	ASSERT (((char *)pc - rep_STR (code)) < rep_STRING_LEN (code)); \
     } while (0)
 
 #ifdef BYTECODE_PROFILE
@@ -572,7 +572,7 @@ vm (repv code, repv consts, int argc, repv *argv,
     
     /* Jump to this label when tail-calling */
 again: {
-    register u_char *pc PC_REG;
+    register unsigned char *pc PC_REG;
     register repv *stackp SP_REG;
     register repv *bindp BP_REG;
     register repv *slotp SLOTS_REG;
@@ -593,7 +593,7 @@ again: {
     bindp = bindstack;
     slotp = slots;
     impurity = 0;
-    pc = rep_STR(code);
+    pc = (unsigned char *) rep_STR(code);
 
     /* Start of the VM fetch-execute sequence. */
     {
@@ -601,7 +601,7 @@ again: {
 	static void *cfa__[256] = { JUMP_TABLE };
 	register void **cfa CFA_REG = cfa__;
 #endif
-	u_int arg;
+	unsigned int arg;
 	repv tmp, tmp2;
 
 	BEGIN_DISPATCH
@@ -2178,7 +2178,7 @@ again: {
 
 	BEGIN_INSN (OP_JMP)
 	do_jmp:
-	    pc = rep_STR(code) + ((pc[0] << ARG_SHIFT) | pc[1]);
+	    pc = (unsigned char *) rep_STR(code) + ((pc[0] << ARG_SHIFT) | pc[1]);
 
 	    /* Test if an interrupt occurred... */
 	    rep_TEST_INT;
@@ -2247,7 +2247,7 @@ again: {
 		    RELOAD;
 		    PUSH(rep_throw_value);
 		    rep_throw_value = rep_NULL;
-		    pc = rep_STR(code) + rep_INT(rep_CAR(item));
+		    pc = (unsigned char *) rep_STR(code) + rep_INT(rep_CAR(item));
 		    impurity--;
 		    SAFE_NEXT;
 		}
