@@ -1,6 +1,6 @@
 /* misc.c -- Miscellaneous functions
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: misc.c,v 1.46 2001/06/15 04:39:44 jsh Exp $
+   $Id: misc.c 2913 2008-08-05 19:11:08Z chrisb $
 
    This file is part of Jade.
 
@@ -122,10 +122,10 @@ strncasecmp (const char *s1, const char *s2, size_t n)
 }
 #endif
 
-u_char *
-rep_str_dupn(const u_char *old, int len)
+char *
+rep_str_dupn(const char *old, int len)
 {
-    u_char *new = rep_alloc(len + 1);
+    char *new = rep_alloc(len + 1);
     if(new)
     {
 	memcpy(new, old, len);
@@ -163,7 +163,7 @@ in the set of all strings in LIST which also match TEMPLATE. If FOLD-CASE
 is t, all matching ignores character case.
 ::end:: */
 {
-    u_char *orig, *match = NULL;
+    char *orig, *match = NULL;
     int matchlen = 0, origlen;
 
     rep_DECLARE1(existing, rep_STRINGP);
@@ -177,12 +177,14 @@ is t, all matching ignores character case.
 	repv arg = rep_CAR(arg_list);
 	if(rep_STRINGP(arg))
 	{
-	    u_char *tmp = rep_STR(arg);
-	    if((rep_NILP(fold) ? strncmp : strncasecmp)(orig, tmp, origlen) == 0)
+	    char *tmp = rep_STR(arg);
+	    if((rep_NILP(fold)
+		? strncmp (orig, tmp, origlen)
+		: strncasecmp (orig, tmp, origlen)) == 0)
 	    {
 		if(match)
 		{
-		    u_char *tmp2 = match + origlen;
+		    char *tmp2 = match + origlen;
 		    tmp += origlen;
 		    while(*tmp2 && *tmp)
 		    {
@@ -221,7 +223,7 @@ containing (DAYS . SECONDS), the number of DAYS since the epoch, and the
 number of seconds since the start of the day (universal time).
 ::end:: */
 {
-    u_long time = rep_time();
+    unsigned long time = rep_time();
     return rep_MAKE_TIME(time);
 }
 
@@ -244,7 +246,7 @@ Ensure that the two parts of TIMESTAMP are mutually consistent. If not
 TIMESTAMP is altered. Returns TIMESTAMP.
 ::end:: */
 {
-    u_long timestamp;
+    unsigned long timestamp;
     rep_DECLARE1(time, rep_TIMEP);
     timestamp = rep_GET_TIME(time);
     rep_CAR(time) = rep_MAKE_INT(timestamp / 86400);
@@ -276,14 +278,17 @@ the same conventions as the template to the C library's strftime function.
 	int len = strftime(buf, sizeof(buf), rep_STR(format), loctime);
 	if(len > 0)
 	    return rep_string_dupn(buf, len);
+	else
+	    return rep_null_string ();
     }
     else
     {
 	char *str = ctime(&timestamp);
-	if(str)
-	    return(rep_string_dupn(str, strlen(str) - 1));
+	if(str != 0)
+	    return rep_string_dupn(str, strlen(str) - 1);
+	else
+	    return rep_null_string ();
     }
-    return rep_NULL;
 }
 
 DEFUN("time-later-p", Ftime_later_p, Stime_later_p, (repv t1, repv t2), rep_Subr2) /*
@@ -293,7 +298,7 @@ time-later-p TIME-STAMP1 TIME-STAMP2
 Returns t when TIME-STAMP1 refers to a later time than TIME-STAMP2.
 ::end:: */
 {
-    u_long time1, time2;
+    unsigned long time1, time2;
     rep_DECLARE1(t1, rep_TIMEP);
     rep_DECLARE2(t2, rep_TIMEP);
     time1 = rep_GET_TIME(t1);
@@ -309,8 +314,9 @@ sleep-for SECONDS [MILLISECONDS]
 Pause for SECONDS (plus the optional MILLISECOND component) length of time.
 ::end:: */
 {
-    rep_DECLARE1(secs, rep_INTP);
-    rep_sleep_for(rep_INT(secs), rep_INTP(msecs) ? rep_INT(msecs) : 0);
+    rep_DECLARE1(secs, rep_NUMERICP);
+    rep_DECLARE2_OPT(msecs, rep_NUMERICP);
+    rep_sleep_for(rep_get_long_int (secs), rep_get_long_int (msecs));
     return Qt;
 }
 
@@ -327,8 +333,10 @@ If neither SECONDS nor MILLISECONDS is defined the command will return
 immediately, using a null timeout.
 ::end:: */
 {
-    return rep_sit_for(((rep_INTP(secs) ? rep_INT(secs) : 0) * 1000)
-		       + (rep_INTP(msecs) ? rep_INT(msecs) : 0));
+    rep_DECLARE1_OPT(secs, rep_NUMERICP);
+    rep_DECLARE2_OPT(msecs, rep_NUMERICP);
+    return rep_sit_for(((rep_get_long_int (secs)) * 1000)
+		       + rep_get_long_int (msecs));
 }
 
 DEFUN("user-login-name", Fuser_login_name, Suser_login_name, (void), rep_Subr0) /*
@@ -350,7 +358,8 @@ the name to return in subsequent calls.
 ::end:: */
 {
     static repv saved_name;
-    if(rep_STRINGP(arg))
+    rep_DECLARE1_OPT (arg, rep_STRINGP);
+    if(arg != Qnil)
     {
 	if(!saved_name)
 	    rep_mark_static(&saved_name);
@@ -368,8 +377,7 @@ Return the path to USER's home directory (a string). When USER is undefined
 the directory of the user who executed Jade is found.
 ::end:: */
 {
-    if(!rep_NILP(user))
-	rep_DECLARE1(user, rep_STRINGP);
+    rep_DECLARE1_OPT(user, rep_STRINGP);
     return rep_user_home_directory(user);
 }
 
@@ -401,71 +409,6 @@ next complete redisplay, unless DISPLAY-NOW is non-nil.
     return string;
 }
 
-/* Try to work out how many bits of randomness rand() will give.. */
-#ifdef HAVE_LRAND48
-# define RAND_BITS 31
-# define rand lrand48
-# define srand srand48
-#else
-# if RAND_MAX == 32768
-#  define RAND_BITS 15
-# elif RAND_MAX == 2147483647
-#  define RAND_BITS 31
-# else
-#  define RAND_BITS 63
-# endif
-#endif
-
-DEFUN("random", Frandom, Srandom, (repv arg), rep_Subr1) /*
-::doc:rep.lang.math#random::
-random [LIMIT]
-
-Produce a pseudo-random number between zero and LIMIT (or the largest positive
-integer representable). If LIMIT is the symbol `t' the generator is seeded
-with the current time of day.
-::end:: */
-{
-    long limit, divisor, val;
-    if(arg == Qt)
-    {
-	srand(time(0));
-	return Qt;
-    }
-
-    if(rep_INTP(arg))
-    {
-	limit = rep_INT(arg);
-	if (limit <= 0)
-	    limit = rep_LISP_MAX_INT;
-    }
-    else
-	limit = rep_LISP_MAX_INT;
-
-    divisor = rep_LISP_MAX_INT / limit;
-    do {
-	val = rand();
-	if (rep_LISP_INT_BITS-1 > RAND_BITS)
-	{
-	    val = (val << RAND_BITS) | rand();
-	    if (rep_LISP_INT_BITS-1 > 2*RAND_BITS)
-	    {
-		val = (val << RAND_BITS) | rand();
-		if (rep_LISP_INT_BITS-1 > 3*RAND_BITS)
-		{
-		    val = (val << RAND_BITS) | rand();
-		    if (rep_LISP_INT_BITS-1 > 4*RAND_BITS)
-			val = (val << RAND_BITS) | rand();
-		}
-	    }
-	}
-	/* Ensure VAL is positive (assumes twos-complement) */
-	val &= ~(~rep_VALUE_CONST(0) << (rep_LISP_INT_BITS-1));
-	val /= divisor;
-    } while(val >= limit);
-
-    return rep_MAKE_INT(val);
-}
-
 DEFUN("translate-string", Ftranslate_string, Stranslate_string, (repv string, repv table), rep_Subr2) /*
 ::doc:rep.data#translate-string:
 translate-string STRING TRANSLATION-TABLE
@@ -479,18 +422,18 @@ Note that the STRING really is modified, no copy is made!
 ::end:: */
 {
     int tablen, slen;
-    register u_char *str;
+    register unsigned char *str;
     rep_DECLARE1(string, rep_STRINGP);
     rep_DECLARE2(table, rep_STRINGP);
     tablen = rep_STRING_LEN(table);
     if(!rep_STRING_WRITABLE_P(string))
 	return(rep_signal_arg_error(string, 1));
-    str = rep_STR(string);
+    str = (unsigned char *)rep_STR(string);
     slen = rep_STRING_LEN(string);
     while(slen-- > 0)
     {
-	register u_char c = *str;
-	*str++ = (c < tablen) ? rep_STR(table)[c] : c;
+	register unsigned char c = *str;
+	*str++ = (c < tablen) ? ((unsigned char *)rep_STR(table))[c] : c;
     }
     rep_string_modified (string);
     return(string);
@@ -705,8 +648,8 @@ rep_misc_init(void)
 
 	for(i = 0; i < 256; i++)
 	{
-	    rep_STR(up)[i] = toupper(i);
-	    rep_STR(down)[i] = tolower(i);
+	    ((unsigned char *)rep_STR(up))[i] = toupper(i);
+	    ((unsigned char *)rep_STR(down))[i] = tolower(i);
 	}
 	rep_STR(up)[256] = 0;
 	rep_STR(down)[256] = 0;
@@ -721,7 +664,7 @@ rep_misc_init(void)
 	repv flatten = rep_make_string (12);
 
 	for(i = 0; i < 10; i++)
-	    rep_STR(flatten)[i] = i;
+	    ((unsigned char *)rep_STR(flatten))[i] = i;
 	rep_STR(flatten)[10] = ' ';
 	rep_STR(flatten)[11] = 0;
 
@@ -729,8 +672,4 @@ rep_misc_init(void)
 	Fset (Qflatten_table, flatten);
     }
     rep_pop_structure (tem);
-
-    tem = rep_push_structure ("rep.lang.math");
-    rep_ADD_SUBR(Srandom);
-    rep_pop_structure (tem);
 }
