@@ -1,6 +1,6 @@
 /* rep-remote.c -- remote filesystem back-end
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
-   $Id: rep-remote.c,v 1.5 2001/09/15 01:35:49 jsh Exp $
+   $Id: rep-remote.c 2913 2008-08-05 19:11:08Z chrisb $
 
    This file is part of librep.
 
@@ -33,6 +33,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <assert.h>
 #include <pwd.h>
 #include <grp.h>
@@ -105,7 +106,7 @@ read_char (void)
 static void
 send_long (long value)
 {
-    u_char lbuf[10];
+    char lbuf[10];
     sprintf (lbuf, "%08lx", value);
     if (write (1, lbuf, 8) != 8)
 	x_perror ("send_long");
@@ -114,7 +115,7 @@ send_long (long value)
 static long
 read_long ()
 {
-    u_char lbuf[10];
+    char lbuf[10];
     if (read (0, lbuf, 8) != 8)
 	x_perror ("read_long");
     lbuf[8] = 0;
@@ -130,7 +131,7 @@ send_string (char *string)
 	x_perror ("send_string");
 }
 
-static u_char *
+static char *
 read_string ()
 {
     long length = read_long ();
@@ -154,8 +155,8 @@ send_errno (int error)
     send_string (strerror (error));
 }
 
-static u_char *
-quote_string (u_char *out, u_char *in)
+static char *
+quote_string (char *out, char *in)
 {
     char c;
     *out++ = '"';
@@ -203,8 +204,8 @@ gid_name (gid_t gid)
     return (gr != 0) ? gr->gr_name : 0;
 }
 
-static u_char *
-output_mode_string (u_char *out, u_long perms)
+static char *
+output_mode_string (char *out, unsigned long perms)
 {
     int i;
     char c = '-';
@@ -218,7 +219,7 @@ output_mode_string (u_char *out, u_long perms)
     out[0] = c;
     for(i = 0; i < 3; i++)
     {
-	u_long xperms = perms >> ((2 - i) * 3);
+	unsigned long xperms = perms >> ((2 - i) * 3);
 	if(xperms & 4)
 	    out[1+i*3] = 'r';
 	if(xperms & 2)
@@ -250,12 +251,12 @@ do_get (int argc, char **argv)
 	FILE *fh = fopen (argv[0], "r");
 	if (fh != 0)
 	{
-	    u_long size = st.st_size;
+	    unsigned long size = st.st_size;
 	    send_success ();
 	    send_long (size);
 	    while (size > 0)
 	    {
-		u_char buf[BUFSIZ];
+		char buf[BUFSIZ];
 		int this = (size > BUFSIZ ? BUFSIZ : size);
 		this = fread (buf, 1, this, fh);
 		if (this == 0)
@@ -285,7 +286,7 @@ do_put (int argc, char **argv)
 	long todo = size;
 	while (todo > 0)
 	{
-	    u_char buf[BUFSIZ];
+	    char buf[BUFSIZ];
 	    int this = (todo > BUFSIZ ? BUFSIZ : todo);
 	    this = read (0, buf, this);
 	    if (this < 0)
@@ -357,7 +358,7 @@ do_cp (int argc, char **argv)
 	    if(fstat(srcf, &statb) == 0)
 		chmod(argv[1], statb.st_mode);
 	    do {
-		u_char buf[BUFSIZ];
+		char buf[BUFSIZ];
 		int wr;
 		rd = read(srcf, buf, BUFSIZ);
 		if(rd < 0)
@@ -437,9 +438,9 @@ do_readdir (int argc, char **argv)
 
 	       suitable for Lisp reading. */
 
-	    u_char nambuf[PATH_MAX];
+	    char nambuf[PATH_MAX];
 	    struct stat st;
-	    u_char buf[3*PATH_MAX], *ptr = buf;
+	    char buf[3*PATH_MAX], *ptr = buf;
 	    strcpy (nambuf, dirname);
 	    strcat (nambuf, de->d_name);
 	    if (lstat (nambuf, &st) == 0)
