@@ -1,6 +1,6 @@
 /* rep_lisp.h -- Data structures/objects for Lisp
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: rep_lisp.h,v 1.72 2002/10/05 18:55:22 jsh Exp $
+   $Id: rep_lisp.h 2913 2008-08-05 19:11:08Z chrisb $
 
    This file is part of Jade.
 
@@ -238,7 +238,7 @@ typedef struct {
 typedef struct rep_type_struct {
     struct rep_type_struct *next;
     char *name;
-    u_int code;
+    unsigned int code;
 
     /* Compares two values, rc is similar to strcmp() */
     int (*compare)(repv val1, repv val2);
@@ -369,7 +369,7 @@ typedef struct rep_string_struct {
     repv car;
 
     /* Pointer to the (zero-terminated) characters */
-    u_char *data;
+    char *data;
 } rep_string;
 
 #define rep_STRING_LEN_SHIFT	8
@@ -393,7 +393,7 @@ typedef struct rep_string_struct {
     rep_ALIGN_CELL(static const rep_string v) = {	\
 	((sizeof(s) - 1) << rep_STRING_LEN_SHIFT)	\
 	| rep_CELL_STATIC_BIT | rep_String,		\
-	(u_char *)s					\
+	(char *)s					\
     }
 
 #define rep_STR(v)	(rep_STRING(v)->data)
