@@ -1,6 +1,6 @@
 /* rep_subrs.h -- mostly LISP subr declarations
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: rep_subrs.h,v 1.73 2002/02/19 05:33:53 jsh Exp $
+   $Id: rep_subrs.h 2941 2008-08-29 14:13:59Z chrisb $
 
    This file is part of Jade.
 
@@ -23,6 +23,10 @@
 
 #include <stdarg.h>
 
+#ifndef inline
+#define inline
+#endif
+
 /* from continuations.c */
 extern int rep_thread_lock;
 extern rep_bool rep_pending_thread_yield;
@@ -47,7 +51,7 @@ extern repv Fall_threads (repv depth);
 extern repv Fthread_forbid (void);
 extern repv Fthread_permit (void);
 extern repv Fthread_name (repv th);
-extern u_long rep_max_sleep_for (void);
+extern unsigned long rep_max_sleep_for (void);
 
 /* from datums.c */
 extern repv Fmake_datum (repv, repv);
@@ -212,11 +216,8 @@ extern repv Qsite_lisp_directory, Qdocumentation_file, Qdocumentation_files;
 extern repv Fquote(repv, repv);
 extern repv Fcar(repv);
 extern repv Fcdr(repv);
-extern repv Flist(repv);
-extern repv Flist_star(repv);
 extern repv Fmake_list(repv, repv);
-extern repv Fappend(repv);
-extern repv Fnconc(repv);
+extern repv Fnconc(repv args);
 extern repv Frplaca(repv, repv);
 extern repv Frplacd(repv, repv);
 extern repv Freverse(repv);
@@ -238,14 +239,12 @@ extern repv Fdelete(repv, repv);
 extern repv Fdelq(repv, repv);
 extern repv Fdelete_if(repv, repv);
 extern repv Fdelete_if_not(repv, repv);
-extern repv Fvector(repv);
 extern repv Fmake_vector(repv, repv);
 extern repv Farrayp(repv);
 extern repv Faset(repv, repv, repv);
 extern repv Faref(repv, repv);
 extern repv Fmake_string(repv, repv);
 extern repv Fsubstring(repv string, repv start, repv end);
-extern repv Fconcat(repv);
 extern repv Flength(repv);
 extern repv Fcopy_sequence(repv);
 extern repv Felt(repv, repv);
@@ -256,14 +255,6 @@ extern repv Fload(repv file, repv noerr_p, repv nopath_p,
 extern repv Fequal(repv, repv);
 extern repv Feq(repv, repv);
 extern repv Fstring_head_eq(repv, repv);
-extern repv Fnum_eq(repv args);
-extern repv Fnum_noteq(repv args);
-extern repv Fgtthan(repv);
-extern repv Fgethan(repv);
-extern repv Fltthan(repv);
-extern repv Flethan(repv);
-extern repv Fmax(repv);
-extern repv Fmin(repv);
 extern repv Fnull(repv);
 extern repv Fatom(repv);
 extern repv Fconsp(repv);
@@ -330,7 +321,7 @@ enum rep_message {
 extern void (*rep_message_fun)(enum rep_message fn, ...);
 
 /* from misc.c */
-extern u_char *rep_str_dupn(const u_char *old, int len);
+extern char *rep_str_dupn(const char *old, int len);
 extern void (*rep_beep_fun)(void);
 extern repv Qoperating_system, Qwindow_system, Qprocess_environment;
 extern repv Qbuild_id_string;
@@ -360,9 +351,9 @@ extern repv Fchar_upcase(repv);
 extern repv Fchar_downcase(repv);
 
 /* from numbers.c */
-extern repv rep_make_long_uint (u_long in);
+extern repv rep_make_long_uint (unsigned long in);
 extern repv rep_make_long_int (long in);
-extern u_long rep_get_long_uint (repv in);
+extern unsigned long rep_get_long_uint (repv in);
 extern long rep_get_long_int (repv in);
 extern repv rep_make_longlong_int (rep_long_long in);
 extern rep_long_long rep_get_longlong_int (repv in);
@@ -386,18 +377,11 @@ extern repv rep_number_max (repv x, repv y);
 extern repv rep_number_min (repv x, repv y);
 extern repv rep_integer_gcd (repv x, repv y);
 extern repv Feql(repv arg1, repv arg2);
-extern repv Fplus(repv);
-extern repv Fminus(repv);
-extern repv Fproduct(repv);
-extern repv Fdivide(repv);
 extern repv Fremainder(repv n1, repv n2);
 extern repv Fmod(repv n1, repv n2);
 extern repv Fquotient(repv n1, repv n2);
 extern repv Flognot(repv);
 extern repv Fnot(repv);
-extern repv Flogior(repv);
-extern repv Flogxor(repv);
-extern repv Flogand(repv);
 extern repv Fplus1(repv);
 extern repv Fsub1(repv);
 extern repv Fash(repv, repv);
@@ -415,7 +399,6 @@ extern repv Facos (repv);
 extern repv Fatan (repv, repv);
 extern repv Fsqrt (repv);
 extern repv Fexpt (repv, repv);
-extern repv Fgcd (repv);
 extern repv Fzerop(repv);
 extern repv Fnumberp(repv);
 extern repv Fintegerp(repv);
@@ -531,7 +514,7 @@ extern repv rep_dumped_non_constants;
 extern int rep_guardian_type;
 extern repv rep_box_pointer (void *p);
 void *rep_unbox_pointer (repv v);
-extern void rep_register_type(u_int code, char *name,
+extern void rep_register_type(unsigned int code, char *name,
 			      int (*compare)(repv, repv),
 			      void (*princ)(repv, repv),
 			      void (*print)(repv, repv),
@@ -542,7 +525,7 @@ extern void rep_register_type(u_int code, char *name,
 			      int (*putc)(repv, int),
 			      int (*puts)(repv, void *, int, rep_bool),
 			      repv (*bind)(repv), void (*unbind)(repv));
-extern u_int rep_register_new_type(char *name,
+extern unsigned int rep_register_new_type(char *name,
 				   int (*compare)(repv, repv),
 				   void (*princ)(repv, repv),
 				   void (*print)(repv, repv),
@@ -555,18 +538,18 @@ extern u_int rep_register_new_type(char *name,
 				   int (*puts)(repv, void *, int, rep_bool),
 				   repv (*bind)(repv),
 				   void (*unbind)(repv));
-extern rep_type *rep_get_data_type(u_int code);
+extern rep_type *rep_get_data_type(unsigned int code);
 extern int rep_value_cmp(repv, repv);
 extern void rep_princ_val(repv, repv);
 extern void rep_print_val(repv, repv);
 extern repv rep_null_string(void);
 extern repv rep_box_string (char *ptr, long len);
 extern repv rep_make_string(long);
-extern repv rep_string_dupn(const u_char *, long);
-extern repv rep_string_dup(const u_char *);
-extern repv rep_concat2(u_char *, u_char *);
-extern repv rep_concat3(u_char *, u_char *, u_char *);
-extern repv rep_concat4(u_char *s1, u_char *s2, u_char *s3, u_char *s4);
+extern repv rep_string_dupn(const char *, long);
+extern repv rep_string_dup(const char *);
+extern repv rep_concat2(char *, char *);
+extern repv rep_concat3(char *, char *, char *);
+extern repv rep_concat4(char *s1, char *s2, char *s3, char *s4);
 extern rep_bool rep_set_string_len(repv, long);
 extern repv rep_list_1(repv);
 extern repv rep_list_2(repv, repv);
@@ -596,12 +579,12 @@ extern void *rep_find_dl_symbol (repv feature, char *symbol);
 
 /* from unix_files.c */
 extern repv rep_lookup_errno(void);
-extern u_long rep_file_length(repv file);
+extern unsigned long rep_file_length(repv file);
 
 /* from unix_main.c */
-extern u_long rep_time(void);
+extern unsigned long rep_time(void);
 extern rep_long_long rep_utime (void);
-extern u_long rep_getpid (void);
+extern unsigned long rep_getpid (void);
 extern void (*rep_register_input_fd_fun)(int fd, void (*callback)(int fd));
 extern void (*rep_deregister_input_fd_fun)(int fd);
 extern void rep_add_event_loop_callback (rep_bool (*callback)(void));
@@ -615,18 +598,18 @@ extern void rep_unix_set_fd_blocking(int fd);
 extern void rep_unix_set_fd_cloexec(int fd);
 extern void rep_sig_restart(int sig, rep_bool flag);
 extern repv rep_event_loop(void);
-extern repv rep_sit_for(u_long timeout_msecs);
-extern repv rep_accept_input_for_callbacks (u_long timeout_msecs,
+extern repv rep_sit_for(unsigned long timeout_msecs);
+extern repv rep_accept_input_for_callbacks (unsigned long timeout_msecs,
 					    int ncallbacks,
 					    void (**callbacks)(int));
-extern repv rep_accept_input_for_fds (u_long timeout_msecs,
+extern repv rep_accept_input_for_fds (unsigned long timeout_msecs,
 				      int nfds, int *fds);
-extern repv rep_accept_input(u_long timeout_msecs, void (*callback)(int));
+extern repv rep_accept_input(unsigned long timeout_msecs, void (*callback)(int));
 extern rep_bool rep_poll_input(int fd);
 
 #ifdef DEBUG_SYS_ALLOC
-extern void *rep_alloc(u_int length);
-extern void *rep_realloc(void *ptr, u_int length);
+extern void *rep_alloc(unsigned int length);
+extern void *rep_realloc(void *ptr, unsigned int length);
 extern void rep_free(void *ptr);
 extern void rep_print_allocations(void);
 #else
@@ -637,6 +620,7 @@ extern void rep_print_allocations(void);
 #endif
 
 extern void (*rep_redisplay_fun)(void);
+extern long (*rep_wait_for_input_fun)(void *inputs, unsigned long timeout_msecs);
 extern int rep_input_timeout_secs;
 extern repv Funix_print_allocations(void);
 
