@@ -1,6 +1,6 @@
 /* sockets.c -- BSD sockets plugin
 
-   $Id: sockets.c,v 1.10 2001/06/29 19:42:27 jsh Exp $
+   $Id: sockets.c 2913 2008-08-05 19:11:08Z chrisb $
 
    Copyright (C) 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -66,7 +66,9 @@ struct rep_socket_struct {
 };
 
 #define IS_ACTIVE		(1 << (rep_CELL16_TYPE_BITS + 0))
+#define IS_REGISTERED		(1 << (rep_CELL16_TYPE_BITS + 1))
 #define SOCKET_IS_ACTIVE(s)	((s)->car & IS_ACTIVE)
+#define SOCKET_IS_REGISTERED(s)	((s)->car & IS_REGISTERED)
 
 #define SOCKETP(x)		rep_CELL16_TYPEP (x, socket_type)
 #define SOCKET(x)		((rep_socket *) rep_PTR (x))
@@ -117,7 +119,9 @@ shutdown_socket (rep_socket *s)
     if (s->sock >= 0)
     {
 	close (s->sock);
-	rep_deregister_input_fd (s->sock);
+
+	if (SOCKET_IS_REGISTERED (s))
+	    rep_deregister_input_fd (s->sock);
     }
 
     DB (("shutdown socket fd %d\n", s->sock));
@@ -126,6 +130,14 @@ shutdown_socket (rep_socket *s)
     s->car &= ~IS_ACTIVE;
 }
 
+static void
+shutdown_socket_and_call_sentinel (rep_socket *s)
+{
+    shutdown_socket (s);
+    if (s->sentinel != Qnil)
+	rep_call_lisp1 (s->sentinel, rep_VAL (s));
+}
+
 static void
 delete_socket (rep_socket *s)
 {
@@ -154,7 +166,7 @@ static void
 client_socket_output (int fd)
 {
     rep_socket *s = socket_for_fd (fd);
-    u_char buf[1025];
+    char buf[1025];
     int actual;
 
     DB (("client_socket_output for %d\n", fd));
@@ -173,9 +185,7 @@ client_socket_output (int fd)
     {
 	/* assume EOF  */
 
-	shutdown_socket (s);
-	if (s->sentinel != Qnil)
-	    rep_call_lisp1 (s->sentinel, rep_VAL (s));
+	shutdown_socket_and_call_sentinel (s);
     }
 }
 
@@ -190,6 +200,7 @@ make_client_socket (int namespace, int style, void *addr, size_t length)
 	{
 	    rep_unix_set_fd_nonblocking (s->sock);
 	    rep_register_input_fd (s->sock, client_socket_output);
+	    s->car |= IS_REGISTERED;
 	    return s;
 	}
 	shutdown_socket (s);
@@ -224,6 +235,7 @@ make_server_socket (int namespace, int style, void *addr, size_t length)
 	    {
 		rep_unix_set_fd_nonblocking (s->sock);
 		rep_register_input_fd (s->sock, server_socket_output);
+		s->car |= IS_REGISTERED;
 		return s;
 	    }
 	}
@@ -439,7 +451,7 @@ subsequently call `close-socket' on the created client.
     struct sockaddr_in in_name;
     struct sockaddr_un un_name;
     void *addr;
-    size_t length;
+    socklen_t length;
     int new;
 
     rep_DECLARE (1, sock, ACTIVE_SOCKET_P (sock));
@@ -462,6 +474,7 @@ subsequently call `close-socket' on the created client.
 	rep_socket *client = make_socket_ (new, s->namespace, s->style);
 	rep_unix_set_fd_nonblocking (new);
 	rep_register_input_fd (new, client_socket_output);
+	client->car |= IS_REGISTERED;
 	client->stream = stream;
 	client->sentinel = sentinel;
 	return rep_VAL (client);
@@ -478,7 +491,7 @@ fill_in_address (rep_socket *s)
 	if (s->namespace == PF_INET)
 	{
 	    struct sockaddr_in name;
-	    size_t length = sizeof (name);
+	    socklen_t length = sizeof (name);
 	    if (getsockname (s->sock, (struct sockaddr *) &name, &length) == 0)
 	    {
 		if (name.sin_addr.s_addr == INADDR_ANY)
@@ -519,7 +532,7 @@ fill_in_peer_address (rep_socket *s)
 	if (s->namespace == PF_INET)
 	{
 	    struct sockaddr_in name;
-	    size_t length = sizeof (name);
+	    socklen_t length = sizeof (name);
 	    if (getpeername (s->sock, (struct sockaddr *) &name, &length) == 0)
 	    {
 		char *addr = inet_ntoa (name.sin_addr);
@@ -641,58 +654,54 @@ poll_for_input (int fd)
 }
 
 /* Returns the number of bytes actually written. */
-static u_int
-blocking_write (int fd, u_char *data, u_int bytes)
+static unsigned int
+blocking_write (rep_socket *s, char *data, unsigned int bytes)
 {
-    u_int done = 0;
+    unsigned int done = 0;
+
+    if (!SOCKET_IS_ACTIVE (s))
+    {
+	Fsignal (Qfile_error, rep_list_2 (rep_VAL (&inactive_socket),
+					  rep_VAL (s)));
+	return -1;
+    }
 
     do {
-	int actual = write (fd, data + done, bytes - done);
+	int actual = write (s->sock, data + done, bytes - done);
 	if (actual < 0)
 	{
 	    if (errno == EAGAIN || errno == EWOULDBLOCK)
 	    {
-		if (!poll_for_input (fd))
-		    goto out;
+		if (!poll_for_input (s->sock))
+		    goto error;
 	    }
 	    else if (errno != EINTR)
-		goto out;
+		goto error;
 	}
 	else
 	    done += actual;
     } while (done < bytes);
 
-out:
     return done;
+
+error:
+    rep_signal_file_error (rep_VAL (s));
+    shutdown_socket_and_call_sentinel (s);
+    return -1;
 }
 
 static int
 socket_putc (repv stream, int c)
 {
     char data = c;
-
-    if (!SOCKET_IS_ACTIVE (SOCKET (stream)))
-    {
-	Fsignal (Qerror, rep_list_2 (rep_VAL (&inactive_socket), stream));
-	return 0;
-    }
-
-    return blocking_write (SOCKET (stream)->sock, &data, 1);
+    return blocking_write (SOCKET (stream), &data, 1);
 }
 
 static int
 socket_puts (repv stream, void *data, int len, rep_bool is_lisp)
 {
-    u_char *buf = is_lisp ? rep_STR(data) : data;
-    int total = 0;
-
-    if (!SOCKET_IS_ACTIVE (SOCKET (stream)))
-    {
-	Fsignal (Qerror, rep_list_2 (rep_VAL (&inactive_socket), stream));
-	return 0;
-    }
-
-    return blocking_write (SOCKET (stream)->sock, buf + total, len - total);
+    char *buf = is_lisp ? rep_STR(data) : data;
+    return blocking_write (SOCKET (stream), buf, len);
 }
 
 static void
