@@ -1,6 +1,6 @@
 /* symbols.c -- Lisp symbol handling
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: symbols.c,v 1.82 2001/08/08 06:15:32 jsh Exp $
+   $Id: symbols.c 2913 2008-08-05 19:11:08Z chrisb $
 
    This file is part of Jade.
 
@@ -149,9 +149,9 @@ static void
 symbol_print(repv strm, repv obj)
 {
     /* output a maximum of 2n chars for a symbol name of length n */
-    u_char *buf = alloca (rep_STRING_LEN (rep_SYM (obj)->name) * 2);
-    register u_char *out = buf;
-    register u_char *s;
+    char *buf = alloca (rep_STRING_LEN (rep_SYM (obj)->name) * 2);
+    register char *out = buf;
+    register char *s;
     rep_bool seen_digit = rep_FALSE;
 
     if (rep_SYMBOL_LITERAL_P (obj))
@@ -188,7 +188,7 @@ symbol_print(repv strm, repv obj)
     s = rep_STR (rep_SYM (obj)->name);
     while (1)
     {
-	u_char c = *s++;
+	char c = *s++;
 	switch (c)
 	{
 	case 0:
@@ -226,10 +226,10 @@ rep_intern_static(repv *symp, repv name)
 	abort();
 }
 
-static inline u_long
-hash(u_char *str)
+static inline unsigned long
+hash(char *str)
 {
-    register u_long value = 0;
+    register unsigned long value = 0;
     while(*str)
 	value = (value * 33) + *str++;
     return(value);
