@@ -1,6 +1,6 @@
 /* unix_main.c -- Miscellaneous functions for Unix
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: unix_main.c,v 1.65 2001/08/08 06:15:32 jsh Exp $
+   $Id: unix_main.c 2927 2008-08-09 06:06:35Z chrisb $
 
    This file is part of Jade.
 
@@ -60,6 +60,7 @@
 #endif
 
 void (*rep_redisplay_fun)(void);
+long (*rep_wait_for_input_fun)(void *inputs, unsigned long timeout_msecs);
 int rep_input_timeout_secs = 1;
 
 
@@ -81,7 +82,13 @@ rep_lookup_errno(void)
 #endif
 }
 
-u_long
+unsigned long
+rep_getpid (void)
+{
+    return getpid ();
+}
+
+unsigned long
 rep_time(void)
 {
     return time(0);
@@ -209,7 +216,7 @@ rep_user_home_directory(repv user)
 repv
 rep_system_name(void)
 {
-    u_char buf[256];
+    char buf[256];
     struct hostent *h;
 
     static repv system_name;
@@ -239,7 +246,7 @@ rep_system_name(void)
 	    system_name = rep_string_dup(*aliases ? *aliases : h->h_name);
 	}
 	else
-	    system_name = rep_string_dup((u_char *)h->h_name);
+	    system_name = rep_string_dup((char *)h->h_name);
     }
     else
 	system_name = rep_string_dup(buf);
@@ -393,7 +400,7 @@ rep_proc_periodically (void)
    actual fds defined by the fdset INPUTS. Return zero if the timeout
    was reached. */
 static int
-wait_for_input(fd_set *inputs, u_long timeout_msecs)
+wait_for_input(fd_set *inputs, unsigned long timeout_msecs)
 {
     fd_set copy;
     int ready = -1;
@@ -424,14 +431,19 @@ wait_for_input(fd_set *inputs, u_long timeout_msecs)
 	}
     }
 
+    /* Allow embedders to override this part of the function. */
+
+    if (rep_wait_for_input_fun != 0)
+	return (*rep_wait_for_input_fun) (inputs, timeout_msecs);
+
     /* Break the timeout into one-second chunks, then check for
        interrupt between each call to select. */
     do {
 	struct timeval timeout;
-	u_long max_sleep = rep_max_sleep_for ();
-	u_long this_timeout_msecs = MIN (timeout_msecs,
+	unsigned long max_sleep = rep_max_sleep_for ();
+	unsigned long this_timeout_msecs = MIN (timeout_msecs,
 					 rep_input_timeout_secs * 1000);
-	u_long actual_timeout_msecs = MIN (this_timeout_msecs, max_sleep);
+	unsigned long actual_timeout_msecs = MIN (this_timeout_msecs, max_sleep);
 
 	timeout.tv_sec = actual_timeout_msecs / 1000;
 	timeout.tv_usec = (actual_timeout_msecs % 1000) * 1000;
@@ -559,7 +571,7 @@ rep_event_loop(void)
 }
 
 repv
-rep_sit_for(u_long timeout_msecs)
+rep_sit_for(unsigned long timeout_msecs)
 {
     fd_set copy;
     int ready;
@@ -577,7 +589,7 @@ rep_sit_for(u_long timeout_msecs)
    invoke any callback function except CALLBACKS. Return Qnil if any
    input was serviced, Qt if the timeout expired, rep_NULL for an error. */
 repv
-rep_accept_input_for_callbacks (u_long timeout_msecs, int ncallbacks,
+rep_accept_input_for_callbacks (unsigned long timeout_msecs, int ncallbacks,
 				void (**callbacks)(int))
 {
     fd_set copy;
@@ -611,7 +623,7 @@ rep_accept_input_for_callbacks (u_long timeout_msecs, int ncallbacks,
    Return Qnil if any input was serviced, Qt if the timeout expired, rep_NULL
    for an error. */
 repv
-rep_accept_input_for_fds (u_long timeout_msecs, int nfds, int *fds)
+rep_accept_input_for_fds (unsigned long timeout_msecs, int nfds, int *fds)
 {
     fd_set copy;
     int ready, i;
@@ -632,7 +644,7 @@ rep_accept_input_for_fds (u_long timeout_msecs, int nfds, int *fds)
 
 /* obsolete, for compatibility only */
 repv
-rep_accept_input(u_long timeout_msecs, void (*callback)(int))
+rep_accept_input(unsigned long timeout_msecs, void (*callback)(int))
 {
     return rep_accept_input_for_callbacks (timeout_msecs, 1, &callback);
 }
@@ -662,7 +674,7 @@ struct alloc_data {
 static struct alloc_data *allocations;
 
 void *
-rep_alloc(u_int length)
+rep_alloc(unsigned int length)
 {
     void *mem;
     length += SIZEOF_ALLOC_DATA;
@@ -684,7 +696,7 @@ rep_alloc(u_int length)
 }
 
 void *
-rep_realloc(void *ptr, u_int length)
+rep_realloc(void *ptr, unsigned int length)
 {
     void *mem;
     length += SIZEOF_ALLOC_DATA;
