@@ -1,6 +1,6 @@
 /* unix_processes.c -- Subprocess handling for Unix
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: unix_processes.c,v 1.76 2001/06/08 17:21:02 jsh Exp $
+   $Id: unix_processes.c 2905 2007-11-03 06:03:15Z jsh $
 
    This file is part of Jade.
 
@@ -334,7 +334,7 @@ read_from_one_fd(struct Proc *pr, int fd)
 {
     repv stream = ((fd != pr->pr_Stdout)
 		    ? pr->pr_ErrorStream : pr->pr_OutputStream);
-    u_char buf[1025];
+    char buf[1025];
     int actual;
     do {
 	if((actual = read(fd, buf, 1024)) > 0)
@@ -380,7 +380,7 @@ read_from_process(int fd)
 }
 
 static int
-write_to_process(repv pr, u_char *buf, int bufLen)
+write_to_process(repv pr, char *buf, int bufLen)
 {
     int act = 0;
     if(!PROCESSP(pr))
@@ -393,13 +393,20 @@ write_to_process(repv pr, u_char *buf, int bufLen)
 	}
 	else
 	{
-	    /* This will block */
-	    act = write(VPROC(pr)->pr_Stdin, buf, bufLen);
-	    if(act < 0)
-	    {
-		rep_signal_file_error(pr);
-		act = 0;
-	    }
+	    do {
+		/* This will block */
+		int this = write(VPROC(pr)->pr_Stdin, buf + act, bufLen - act);
+		if (this < 0)
+		{
+		    if (errno != EINTR)
+		    {
+			rep_signal_file_error(pr);
+			break;
+		    }
+		}
+		else
+		    act += this;
+	    } while (act < bufLen);
 	}
     }
     else
@@ -549,7 +556,7 @@ child_build_environ (void)
    stdin connected to the file SYNC_INPUT. Otherwise this function returns
    immediately after starting the process.  */
 static rep_bool
-run_process(struct Proc *pr, char **argv, u_char *sync_input)
+run_process(struct Proc *pr, char **argv, char *sync_input)
 {
     rep_bool rc = rep_FALSE;
     if(PR_DEAD_P(pr))
@@ -799,7 +806,7 @@ run_process(struct Proc *pr, char **argv, u_char *sync_input)
 		else
 		{
 		    /* Run synchronously.  */
-		    u_char buf[1025];
+		    char buf[1025];
 		    int actual;
 		    fd_set inputs;
 		    rep_bool done_out = rep_FALSE, done_err = rep_FALSE;
@@ -1013,7 +1020,7 @@ static void
 proc_prin(repv strm, repv obj)
 {
     struct Proc *pr = VPROC(obj);
-    u_char buf[40];
+    char buf[40];
     rep_stream_puts(strm, "#<process", -1, rep_FALSE);
     if(PR_RUNNING_P(pr))
     {
@@ -1044,7 +1051,7 @@ static int
 proc_putc(repv stream, int c)
 {
     char tmps[2];
-    tmps[0] = (u_char)c;
+    tmps[0] = (char)c;
     tmps[1] = 0;
     return write_to_process(stream, tmps, 1);
 }
@@ -1052,7 +1059,7 @@ proc_putc(repv stream, int c)
 static int
 proc_puts(repv stream, void *data, int len, rep_bool is_lisp)
 {
-    u_char *buf = is_lisp ? rep_STR(data) : data;
+    char *buf = is_lisp ? rep_STR(data) : data;
     return write_to_process(stream, buf, len);
 }
 
@@ -1110,6 +1117,20 @@ If the DIR parameter is nil it will be inherited from the
 	return rep_mem_error();
 }
 
+DEFUN("close-process", Fclose_process,
+      Sclose_process, (repv proc), rep_Subr1) /*
+::doc:rep.io.processes#close-process::
+close-processes [PROCESS]
+
+Closes the stdin, stdout, and stderr streams of the asynchronous process-
+object PROCESS.
+::end:: */
+{
+    rep_DECLARE1(proc, PROCESSP);
+    close_proc_files(VPROC(proc));
+    return(Qnil); 
+}
+
 DEFUN("start-process", Fstart_process, Sstart_process, (repv arg_list), rep_SubrN) /*
 ::doc:rep.io.processes#start-process::
 start-process [PROCESS] [PROGRAM] [ARGS...]
@@ -1905,12 +1926,14 @@ Note that output includes notification of process termination.
 ::end:: */
 {
     repv result = Qt;
+    rep_DECLARE2_OPT(secs, rep_NUMERICP);
+    rep_DECLARE3_OPT(msecs, rep_NUMERICP);
     /* Only wait for output if nothing already waiting. */
     if(!got_sigchld && !notify_chain)
     {
 	result = (rep_accept_input_for_callbacks
-		  ((rep_INTP(secs) ? rep_INT(secs) * 1000 : 0)
-		   + (rep_INTP(msecs) ? rep_INT(msecs) : 0),
+		  ((rep_get_long_int (secs) * 1000)
+		   + (rep_get_long_int (msecs)),
 		   n_input_handlers, input_handlers));
     }
     if(got_sigchld || notify_chain)
@@ -1936,6 +1959,8 @@ Note that output includes notification of process termination.
 {
     repv result = Qt;
     rep_DECLARE1 (process, PROCESSP);
+    rep_DECLARE2_OPT(secs, rep_NUMERICP);
+    rep_DECLARE3_OPT(msecs, rep_NUMERICP);
 
     /* Only wait for output if nothing already waiting. */
     if (got_sigchld)
@@ -1947,8 +1972,8 @@ Note that output includes notification of process termination.
 	fds[0] = VPROC (process)->pr_Stdout;
 	fds[1] = VPROC (process)->pr_Stderr;
 	result = (rep_accept_input_for_fds
-		  ((rep_INTP(secs) ? rep_INT(secs) * 1000 : 0)
-		   + (rep_INTP(msecs) ? rep_INT(msecs) : 0), 2, fds));
+		  ((rep_get_long_int (secs) * 1000)
+		   + rep_get_long_int (msecs), 2, fds));
     }
 
     if (got_sigchld)
@@ -1969,10 +1994,12 @@ rep_system (char *command)
 {
     int pid, status;
     int interrupt_count = 0;
+
     pid = fork ();
     switch (pid)
     {
 	char *argv[4];
+	repv ret;
 	DEFSTRING (cant_fork, "can't fork ()");
 
     case -1:
@@ -1990,8 +2017,13 @@ rep_system (char *command)
 	_exit (255);
 
     default:
-	do {
+	ret = Qnil;
+	rep_sig_restart (SIGCHLD, rep_FALSE);
+	while (1)
+	{
 	    struct timeval timeout;
+	    int x;
+
 	    rep_TEST_INT_SLOW;
 	    if (rep_INTERRUPTP)
 	    {
@@ -2002,26 +2034,30 @@ rep_system (char *command)
 		if (rep_throw_value == rep_int_cell)
 		    rep_throw_value = rep_NULL;
 	    }
-	    timeout.tv_sec = 1;
-	    timeout.tv_usec = 0;
-	    rep_sig_restart (SIGCHLD, rep_FALSE);
-	    select (FD_SETSIZE, NULL, NULL, NULL, &timeout);
-	    rep_sig_restart (SIGCHLD, rep_TRUE);
-	    switch (waitpid(pid, &status, WNOHANG))
+
+	    x = waitpid (pid, &status, WNOHANG);
+	    if (x == -1)
 	    {
-	    case 0:
-		break;
-	    case -1:
 		if (errno != EINTR && errno != EAGAIN)
 		{
 		    DEFSTRING (cant_waitpid, "can't waitpid ()");
-		    return Fsignal (Qerror, Fcons (rep_VAL (&cant_waitpid), Qnil));
+		    ret = Fsignal (Qerror,
+				   Fcons (rep_VAL (&cant_waitpid), Qnil));
+		    break;
 		}
-		break;
-	    default:
-		return rep_MAKE_INT (status);
 	    }
-	} while (1);
+	    else if (x == pid)
+	    {
+		ret = rep_MAKE_INT (status);
+		break;
+	    }
+
+	    timeout.tv_sec = 1;
+	    timeout.tv_usec = 0;
+	    select (FD_SETSIZE, NULL, NULL, NULL, &timeout);
+	}
+	rep_sig_restart (SIGCHLD, rep_TRUE);
+	return ret;
     }
 }
 
@@ -2050,6 +2086,7 @@ rep_proc_init(void)
     rep_INTERN(socketpair);
 
     tem = rep_push_structure ("rep.io.processes");
+    rep_ADD_SUBR(Sclose_process);
     rep_ADD_SUBR(Smake_process);
     rep_ADD_SUBR(Sstart_process);
     rep_ADD_SUBR(Scall_process);
