@@ -1,6 +1,6 @@
 /* values.c -- Handling of Lisp data (includes garbage collection)
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: values.c,v 1.65 2000/09/03 12:36:05 john Exp $
+   $Id: values.c 2913 2008-08-05 19:11:08Z chrisb $
 
    This file is part of Jade.
 
@@ -77,11 +77,11 @@ DEFSYM(after_gc_hook, "after-gc-hook");
 #define TYPE_HASH_SIZE 32
 #define TYPE_HASH(type) (((type) >> 1) & (TYPE_HASH_SIZE-1))
 
-static u_int next_free_type = 0;
+static unsigned int next_free_type = 0;
 static rep_type *data_types[TYPE_HASH_SIZE];
 
 void
-rep_register_type(u_int code, char *name,
+rep_register_type(unsigned int code, char *name,
 		  int (*compare)(repv, repv),
 		  void (*princ)(repv, repv),
 		  void (*print)(repv, repv),
@@ -119,7 +119,7 @@ rep_register_type(u_int code, char *name,
     data_types[TYPE_HASH(code)] = t;
 }
 
-u_int
+unsigned int
 rep_register_new_type(char *name,
 		      int (*compare)(repv, repv),
 		      void (*princ)(repv, repv),
@@ -134,7 +134,7 @@ rep_register_new_type(char *name,
 		      repv (*bind)(repv),
 		      void (*unbind)(repv))
 {
-    u_int code;
+    unsigned int code;
     assert(next_free_type != 256);
     code = (next_free_type++ << rep_CELL16_TYPE_SHIFT) | rep_CELL_IS_8 | rep_CELL_IS_16;
     rep_register_type(code, name, compare, princ, print,
@@ -144,7 +144,7 @@ rep_register_new_type(char *name,
 }
 
 rep_type *
-rep_get_data_type(u_int code)
+rep_get_data_type(unsigned int code)
 {
     rep_type *t = data_types[TYPE_HASH(code)];
     while (t != 0 && t->code != code)
@@ -278,7 +278,7 @@ rep_make_string(long len)
 }
 
 repv
-rep_string_dupn(const u_char *src, long slen)
+rep_string_dupn(const char *src, long slen)
 {
     rep_string *dst = rep_STRING(rep_make_string(slen + 1));
     if(dst != NULL)
@@ -290,13 +290,13 @@ rep_string_dupn(const u_char *src, long slen)
 }
 
 repv
-rep_string_dup(const u_char *src)
+rep_string_dup(const char *src)
 {
     return rep_string_dupn(src, strlen(src));
 }
 
 repv
-rep_concat2(u_char *s1, u_char *s2)
+rep_concat2(char *s1, char *s2)
 {
     int len = strlen(s1) + strlen(s2);
     repv res = rep_make_string(len + 1);
@@ -305,7 +305,7 @@ rep_concat2(u_char *s1, u_char *s2)
 }
 
 repv
-rep_concat3(u_char *s1, u_char *s2, u_char *s3)
+rep_concat3(char *s1, char *s2, char *s3)
 {
     int len = strlen(s1) + strlen(s2) + strlen(s3);
     repv res = rep_make_string(len + 1);
@@ -314,7 +314,7 @@ rep_concat3(u_char *s1, u_char *s2, u_char *s3)
 }
 
 repv
-rep_concat4(u_char *s1, u_char *s2, u_char *s3, u_char *s4)
+rep_concat4(char *s1, char *s2, char *s3, char *s4)
 {
     int len = strlen(s1) + strlen(s2) + strlen(s3) + strlen(s4);
     repv res = rep_make_string(len + 1);
@@ -998,6 +998,7 @@ last garbage-collection is greater than `garbage-threshold'.
     }
 
     rep_mark_regexp_data();
+    rep_mark_origins ();
 
 #ifdef HAVE_DYNAMIC_LOADING
     rep_mark_dl_data();
@@ -1009,15 +1010,18 @@ last garbage-collection is greater than `garbage-threshold'.
     {
 	rep_MARKVAL(lc->fun);
 	rep_MARKVAL(lc->args);
+	rep_MARKVAL(lc->current_form);
 	rep_MARKVAL(lc->saved_env);
 	rep_MARKVAL(lc->saved_structure);
-	/* don't bother marking `args_evalled_p' it's always `nil' or `t'  */
 	lc = lc->next;
     }
 
     /* move and mark any guarded objects that became inaccessible */
     run_guardians ();
 
+    /* look for dead weak references */
+    rep_scan_weak_refs ();
+
     /* Finished marking, start sweeping. */
 
     rep_sweep_tuples ();
